<?php
/***********************************************************************

  Copyright (C) 2002-2005  Rickard Andersson (rickard@punbb.org)

  This file is part of PunBB.

  PunBB is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  PunBB is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

// Make sure no one attempts to run this script "directly"
if (!defined('PUN'))
	exit;


// Here you can add additional smilies if you like (please note that you must escape singlequote and backslash)
$smiley_text = array(':)', '=)', ':|', '=|', ':(', '=(', ':D', '=D', ':o', ':O', ';)', ':/', ':P', ':lol:', ':mad:', ':rolleyes:', ':cool:');
$smiley_img = array('smile.png', 'smile.png', 'neutral.png', 'neutral.png', 'sad.png', 'sad.png', 'big_smile.png', 'big_smile.png', 'yikes.png', 'yikes.png', 'wink.png', 'hmm.png', 'tongue.png', 'lol.png', 'mad.png', 'roll.png', 'cool.png');

// Uncomment the next row if you add smilies that contain any of the characters &"'<>
//$smiley_text = array_map('pun_htmlspecialchars', $smiley_text);


//
// Make sure all BBCodes are lower case and do a little cleanup
//
function preparse_bbcode($text, &$errors, $is_signature = false)
{
	// Change all simple BBCodes to lower case
	$a = array('[B]', '[I]', '[U]', '[/B]', '[/I]', '[/U]', '[S]', '[/S]');
	$b = array('[b]', '[i]', '[u]', '[/b]', '[/i]', '[/u]', '[s]', '[/s]'); 
	$text = str_replace($a, $b, $text);

	// Do the more complex BBCodes (also strip excessive whitespace and useless quotes)
	$a = array( '#\[url=("|\'|)(.*?)\\1\]\s*#i',
				'#\[url\]\s*#i',
				'#\s*\[/url\]#i',
				'#\[email=("|\'|)(.*?)\\1\]\s*#i',
				'#\[email\]\s*#i',
				'#\s*\[/email\]#i',
				'#\[img\]\s*(.*?)\s*\[/img\]#is',
				'#\[colou?r=("|\'|)(.*?)\\1\](.*?)\[/colou?r\]#is');

	$b = array(	'[url=$2]',
				'[url]',
				'[/url]',
				'[email=$2]',
				'[email]',
				'[/email]',
				'[img]$1[/img]',
				'[color=$2]$3[/color]');

	if (!$is_signature)
	{
		// For non-signatures, we have to do the quote and code tags as well
		$a[] = '#\[quote=(&quot;|"|\'|)(.*?)\\1\]\s*#i';
		$a[] = '#\[quote\]\s*#i';
		$a[] = '#\s*\[/quote\]\s*#i';
		$a[] = '#\[code\][\r\n]*(.*?)\s*\[/code\]\s*#is';

		$b[] = '[quote=$1$2$1]';
		$b[] = '[quote]';
		$b[] = '[/quote]'."\n";
		$b[] = '[code]$1[/code]'."\n";
	}

	// Run this baby!
	$text = preg_replace($a, $b, $text);

	if (!$is_signature)
	{
		$overflow = check_tag_order($text, $error);

		if ($error)
			// A BBCode error was spotted in check_tag_order()
			$errors[] = $error;
		else if ($overflow)
			// The quote depth level was too high, so we strip out the inner most quote(s)
			$text = substr($text, 0, $overflow[0]).substr($text, $overflow[1], (strlen($text) - $overflow[0]));
	}
	else
	{
		global $lang_prof_reg;

		if (preg_match('#\[quote=(&quot;|"|\'|)(.*)\\1\]|\[quote\]|\[/quote\]|\[code\]|\[/code\]#i', $text))
			message($lang_prof_reg['Signature quote/code']);
	}

	return trim($text);
}


//
// Parse text and make sure that [code] and [quote] syntax is correct
//
function check_tag_order($text, &$error)
{
	global $lang_common;

	// The maximum allowed quote depth
	$max_depth = 3;

	$cur_index = 0;
	$q_depth = 0;

	while (true)
	{
		// Look for regular code and quote tags
		$c_start = strpos($text, '[code]');
		$c_end = strpos($text, '[/code]');
		$q_start = strpos($text, '[quote]');
		$q_end = strpos($text, '[/quote]');

		// Look for [quote=username] style quote tags
		if (preg_match('#\[quote=(&quot;|"|\'|)(.*)\\1\]#sU', $text, $matches))
			$q2_start = strpos($text, $matches[0]);
		else
			$q2_start = 65536;

		// Deal with strpos() returning false when the string is not found
		// (65536 is one byte longer than the maximum post length)
		if ($c_start === false) $c_start = 65536;
		if ($c_end === false) $c_end = 65536;
		if ($q_start === false) $q_start = 65536;
		if ($q_end === false) $q_end = 65536;

		// If none of the strings were found
		if (min($c_start, $c_end, $q_start, $q_end, $q2_start) == 65536)
			break;

		// We are interested in the first quote (regardless of the type of quote)
		$q3_start = ($q_start < $q2_start) ? $q_start : $q2_start;

		// We found a [quote] or a [quote=username]
		if ($q3_start < min($q_end, $c_start, $c_end))
		{
			$step = ($q_start < $q2_start) ? 7 : strlen($matches[0]);

			$cur_index += $q3_start + $step;

			// Did we reach $max_depth?
			if ($q_depth == $max_depth)
				$overflow_begin = $cur_index - $step;

			++$q_depth;
			$text = substr($text, $q3_start + $step);
		}

		// We found a [/quote]
		else if ($q_end < min($q_start, $c_start, $c_end))
		{
			if ($q_depth == 0)
			{
				$error = $lang_common['BBCode error'].' '.$lang_common['BBCode error 1'];
				return;
			}

			$q_depth--;
			$cur_index += $q_end+8;

			// Did we reach $max_depth?
			if ($q_depth == $max_depth)
				$overflow_end = $cur_index;

			$text = substr($text, $q_end+8);
		}

		// We found a [code]
		else if ($c_start < min($c_end, $q_start, $q_end))
		{
			// Make sure there's a [/code] and that any new [code] doesn't occur before the end tag
			$tmp = strpos($text, '[/code]');
			$tmp2 = strpos(substr($text, $c_start+6), '[code]');
			if ($tmp2 !== false)
				$tmp2 += $c_start+6;

			if ($tmp === false || ($tmp2 !== false && $tmp2 < $tmp))
			{
				$error = $lang_common['BBCode error'].' '.$lang_common['BBCode error 2'];
				return;
			}
			else
				$text = substr($text, $tmp+7);

			$cur_index += $tmp+7;
		}

		// We found a [/code] (this shouldn't happen since we handle both start and end tag in the if clause above)
		else if ($c_end < min($c_start, $q_start, $q_end))
		{
			$error = $lang_common['BBCode error'].' '.$lang_common['BBCode error 3'];
			return;
		}
	}

	// If $q_depth <> 0 something is wrong with the quote syntax
	if ($q_depth)
	{
		$error = $lang_common['BBCode error'].' '.$lang_common['BBCode error 4'];
		return;
	}
	else if ($q_depth < 0)
	{
		$error = $lang_common['BBCode error'].' '.$lang_common['BBCode error 5'];
		return;
	}

	// If the quote depth level was higher than $max_depth we return the index for the
	// beginning and end of the part we should strip out
	if (isset($overflow_begin))
		return array($overflow_begin, $overflow_end);
	else
		return null;
}


//
// Split text into chunks ($inside contains all text inside $start and $end, and $outside contains all text outside)
//
function split_text($text, $start, $end)
{
	global $pun_config;

	$tokens = explode($start, $text);

	$outside[] = $tokens[0];

	$num_tokens = count($tokens);
	for ($i = 1; $i < $num_tokens; ++$i)
	{
		$temp = explode($end, $tokens[$i]);
		$inside[] = $temp[0];
		$outside[] = $temp[1];
	}

	if ($pun_config['o_indent_num_spaces'] != 8 && $start == '[code]')
	{
		$spaces = str_repeat(' ', $pun_config['o_indent_num_spaces']);
		$inside = str_replace("\t", $spaces, $inside);
	}

	return array($inside, $outside);
}


//
// Truncate URL if longer than 55 characters (add http:// or ftp:// if missing)
//
function handle_url_tag($url, $link = '')
{
	global $pun_user;

	$full_url = str_replace(array(' ', '\'', '`', '"'), array('%20', '', '', ''), $url);
	if (strpos($url, 'www.') === 0)			// If it starts with www, we add http://
		$full_url = 'http://'.$full_url;
	else if (strpos($url, 'ftp.') === 0)	// Else if it starts with ftp, we add ftp://
		$full_url = 'ftp://'.$full_url;
	else if (!preg_match('#^([a-z0-9]{3,6})://#', $url, $bah)) 	// Else if it doesn't start with abcdef://, we add http://
		$full_url = 'http://'.$full_url;

	// Ok, not very pretty :-)
	$link = ($link == '' || $link == $url) ? ((strlen($url) > 55) ? substr($url, 0 , 39).' &hellip; '.substr($url, -10) : $url) : stripslashes($link);

	return '<a href="'.$full_url.'">'.$link.'</a>';
}


//
// Turns an URL from the [img] tag into an <img> tag or a <a href...> tag
//
function handle_img_tag($url, $is_signature = false)
{
	global $lang_common, $pun_config, $pun_user;

	$img_tag = '<a href="'.$url.'">&lt;'.$lang_common['Image link'].'&gt;</a>';

	if ($is_signature && $pun_user['show_img_sig'] != '0')
		$img_tag = '<img class="sigimage" src="'.$url.'" alt="'.htmlspecialchars($url).'" />';
	else if (!$is_signature && $pun_user['show_img'] != '0')
		$img_tag = '<img class="postimg" src="'.$url.'" alt="'.htmlspecialchars($url).'" />';

	return $img_tag;
}


//
// Convert BBCodes to their HTML equivalent
//
function do_bbcode($text)
{
	global $lang_common, $pun_user;

	if (strpos($text, 'quote') !== false)
	{
		$text = str_replace('[quote]', '</p><blockquote><div class="incqbox"><p>', $text);
		$text = preg_replace('#\[quote=(&quot;|"|\'|)(.*)\\1\]#seU', '"</p><blockquote><div class=\"incqbox\"><h4>".str_replace(array(\'[\', \'\\"\'), array(\'&#91;\', \'"\'), \'$2\')." ".$lang_common[\'wrote\'].":</h4><p>"', $text);
		$text = preg_replace('#\[\/quote\]\s*#', '</p></div></blockquote><p>', $text);
	}

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
//++++++++++++++++++++++++++++++++++++++++++++++++++ Start Easy Visual BBCode ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

	$pattern = array('#\[b\](.*?)\[/b\]#s',
					 '#\[i\](.*?)\[/i\]#s',
					 '#\[u\](.*?)\[/u\]#s',
					 
					 '#\[url\]([^\[]*?)\[/url\]#e',
					 '#\[url=([^\[]*?)\](.*?)\[/url\]#e',
					 '#\[email\]([^\[]*?)\[/email\]#',
					 '#\[email=([^\[]*?)\](.*?)\[/email\]#',
					 '#\[color=([a-zA-Z]*|\#?[0-9a-fA-F]{6})](.*?)\[/color\]#s',					 
					 
				//++++++++++++++++++++++++++++++++++++++//	 
					 '#\[s\](.*?)\[/s\]#s',
					 
					 '#\[center\](.*?)\[/center\]#s',
					 '#\[left\](.*?)\[/left\]#s',
					 '#\[right\](.*?)\[/right\]#s',
					 '#\[justify\](.*?)\[/justify\]#s',
					 '#\[indent\](.*?)\[/indent\]#s',
					 					 
					 '#\[size=([0-9]*)](.*?)\[/size\]#s',
					 '#\[font=(.*?)\](.*?)\[/font\]#',

					 '#\[highlight\](.*?)\[/highlight\]#',
					 
					 
				
				//++++++++++++++++++++++++++++++++++++++//
				/* 	If you need some Tables - here are the BBCodes for that, but I haven't included them in the "mod_easy_bbcode.php":
					A table could look like this
				
			 		[table]
					[caption] TableHeading[/caption]
					[tr][td]Testing1[/td][td]Testing2[/td][/tr]
					[tr][td]Testing3[/td][td]Testing4[/td][/tr]
					[/table]
				*/ 
					 
					 '#\[table\](.*?)\[/table\]#s',
					 '#\[caption\](.*?)\[/caption\]#s',
					 '#\[th\](.*?)\[/th\]#s',
					 '#\[tr\](.*?)\[/tr\]#s',
					 '#\[td\](.*?)\[/td\]#s',
				//++++++++++++++++++++++++++++++++++++++//
				
					 
					 '#\[pre\](.*?)\[/pre\]#s',
					 '#\[sup\](.*?)\[/sup\]#',
					 '#\[sub\](.*?)\[/sub\]#',
					 
					 					 
					 '#\[ol\](.*?)\[/ol\]#s',
					 '#\[ul\](.*?)\[/ul\]#s',
					 '#\[li\](.*?)\[/li\]#s',
					 
					 '#\[hr\]#s',
				//++++++++++++++++++++++++++++++++++++++//	 
					 



					 					 
					 
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++ Video Portals +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//				 
					 
					 
					 '#\[youtube\](.*?)\[/youtube\]#s',
					 '#\[googlevid\](.*?)\[/googlevid\]#s',
					 '#\[myvideo\](.*?)\[/myvideo\]#s',
					 '#\[clipfish\](.*?)\[/clipfish\]#s',
					 '#\[dailymotion\](.*?)\[/dailymotion\]#s',
					 '#\[metacafe\](.*?)\[/metacafe\]#s',
					 '#\[ifilm\](.*?)\[/ifilm\]#s',
					 '#\[sevenload\](.*?)\[/sevenload\]#s',
					 '#\[garagetv\](.*?)\[/garagetv\]#s',
					 '#\[revver\](.*?)\[/revver\]#s',
					 '#\[guba\](.*?)\[/guba\]#s',
					 '#\[myspace\](.*?)\[/myspace\]#s',
					 '#\[yahoo\](.*?)&amp;(.*?)\[/yahoo\]#s',
					 '#\[aniboom\](.*?)\[/aniboom\]#s',
					 '#\[veoh\](.*?)\[/veoh\]#s',
					 '#\[videojug\](.*?)\[/videojug\]#s',
					 '#\[vsocial\](.*?)\[/vsocial\]#s',
					 '#\[esnips\](.*?)\[/esnips\]#s',
					 '#\[brightcove\](.*?)\[/brightcove\]#s',
					 					 					 
					 '#\[megavideo\](.*?)\[/megavideo\]#s',	// this one shows with "start-picture", but need the Video ID string from the "embed" Code
					 '#\[megavideo2\](.*?)\[/megavideo2\]#s',	// this one shows no "start-picture" in the player, but needs only the Video ID from the URL
					 
					 
					 '#\[stage6 width=([0-9,.]*) height=([0-9,.]*)\](.*?)\[/stage6\]#s',//******* set dimensions in BBCode ********//
					 '#\[stage6\](.*?)\[/stage6\]#s',
					 
					 '#\[virb width=([0-9,.]*) height=([0-9,.]*)\](.*?)\[/virb\]#s',//******* set dimensions in BBCode ********//
					 '#\[virb\](.*?)\[/virb\]#s',	 
	 
	 
					 '#\[flv\](.*?)\[/flv\]#',
					 
					 '#\[mp3\](.*?)\[/mp3\]#',
					 
					 '#\[divx\](.*?)\[/divx\]#',
					 '#\[divx width=([0-9]*) height=([0-9]*)\](.*?)\[/divx\]#',
					 
					 '#\[swf height=([0-9]*)\](.*?)\[/swf\]#',			
					 '#\[swf width=([0-9]*) height=([0-9]*)\](.*?)\[/swf\]#',
					 '#\[swf\](.*?)\[/swf\]#',	
					 
					 '#\[quicktime\](.*?)\[/quicktime\]#',
					 '#\[quicktime width=([0-9]*) height=([0-9]*)\](.*?)\[/quicktime\]#',
					  
					 '#\[wmp width=([0-9]*) height=([0-9]*)\](.*?)\[/wmp\]#',
					 
					 
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//					 
				 	 
					 
					 );// end array - don't remove //
					 
		
	
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//		
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//					 

	$replace = array('<strong>$1</strong>',
					 '<em>$1</em>',
					 '<span class="bbu">$1</span>',
					 					 
					 'handle_url_tag(\'$1\')',
					 'handle_url_tag(\'$1\', \'$2\')',
					 '<a href="mailto:$1">$1</a>',
					 '<a href="mailto:$1">$2</a>',
					 '<span style="color: $1">$2</span>',
					 
					 
			//++++++++++++++++++++++++++++++++++++++//		 					 
					 '<span class="bbs">$1</span>',
					 '<p class="bbcenter">$1</p>',
					 '<p class="bbleft">$1</p>',
					 '<p class="bbright">$1</p>',
					 '<p class="bbjustify">$1</p>',
					 '<p class="bbindent">$1</p>',
					 
					 
					 '<span style="font-size: $1px">$2</span>',
					 '<span style="font-family: $1">$2</span>',

					 '<span class="bbhighlight">$1</span>',
					 
			//++++++++++++++++++++++++++++++++++++++//
			/* 	If you need some Tables - here are the BBCodes for that, but I haven't included them in the "mod_easy_bbcode.php":
				A table could look like this
				
			 	[table]
				[caption] TableHeading[/caption]
				[tr][td]Testing1[/td][td]Testing2[/td][/tr]
				[tr][td]Testing3[/td][td]Testing4[/td][/tr]
				[/table]
			*/
		 
					 '<table>$1</table>',
					 '<caption>$1</caption>',
					 '<th>$1</th>',
					 '<tr>$1</tr>',
					 '<td>$1</td>',
					 			 
			//++++++++++++++++++++++++++++++++++++++//	
				 
					 '<pre>$1</pre>',
					 '<sup>$1</sup>',
					 '<sub>$1</sub>',
					 					 
					 				 			 
					 '<ol>$1</ol>',
					 '<ul>$1</ul>',
					 '<li>$1</li>',
					 
					 '<hr/>',
			//++++++++++++++++++++++++++++++++++++++//


					 		 				 
					 


//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++ Video Portals +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//


					 
//****** embed YouTube Videos ***********************************************	
'<div class="bbvideo"><object width="425" height="350" align="top" data="http://www.youtube.com/v/$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.youtube.com/v/$1" /><param name="quality" value="best" /><embed src="http://www.youtube.com/v/$1" width="425" height="350" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end YouTube Videos *************************************************
					 					 
					 
//****** embed Google Videos ************************************************
'<div class="bbvideo"><object width="425" height="364" align="top" data="http://video.google.com/googleplayer.swf?docId=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://video.google.com/googleplayer.swf?docId=$1" /><param name="quality" value="best" /><embed src="http://video.google.com/googleplayer.swf?docId=$1" width="425" height="364" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Google Videos **************************************************
					 					 
					 
//****** embed MyVideo ******************************************************
'<div class="bbvideo"><object width="470" height="406" align="top" data="http://www.myvideo.de/movie/$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.myvideo.de/movie/$1" /><param name="quality" value="best" /><embed src="http://www.myvideo.de/movie/$1" width="470" height="406" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end MyVideo ********************************************************
					 
					  
//****** embed ClipFish *****************************************************
'<div class="bbvideo"><object width="464" height="380" align="top" data="http://www.clipfish.com/videoplayer.swf?as=0&videoid=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.clipfish.com/videoplayer.swf?as=0&videoid=$1" /><param name="quality" value="best" /><embed src="http://www.clipfish.com/videoplayer.swf?as=0&videoid=$1" width="464" height="380" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end ClipFish *******************************************************
					 				 
					 
//****** embed Dailymotion Videos *******************************************	
'<div class="bbvideo"><object width="520" height="406" align="top" data="http://www.dailymotion.com/swf/$1.swf" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.dailymotion.com/swf/$1.swf" /><param name="quality" value="best" /><embed src="http://www.dailymotion.com/swf/$1" width="520" height="406" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Dailymotion Videos *********************************************
					 
					 
//****** embed Metacafe Videos **********************************************	
'<div class="bbvideo"><object width="400" height="345" align="top" data="http://www.metacafe.com/fplayer/$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.metacafe.com/fplayer/$1" /><param name="quality" value="best" /><embed src="http://www.metacafe.com/fplayer/$1.swf" width="400" height="345" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Metacafe Videos ************************************************	
					 
					
//****** embed iFilm Videos *************************************************	
'<div class="bbvideo"><object width="448" height="365" align="top" data="http://www.ifilm.com/efp?flvbaseclip=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.ifilm.com/efp?flvbaseclip=$1" /><param name="quality" value="best" /><embed src="http://www.ifilm.com/efp?flvbaseclip=$1" width="448" height="365" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end iFilm Videos ***************************************************	
					 				 
					 
//****** embed Sevenload Videos *********************************************	
'<div class="bbvideo"><object width="425" height="350" align="top" data="http://page.sevenload.com/swf/player.swf?id=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://page.sevenload.com/swf/player.swf?id=$1" /><param name="quality" value="best" /><embed src="http://page.sevenload.com/swf/player.swf?id=$1" width="425" height="350" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Sevenload Videos ***********************************************
					 
					 
//****** embed GarageTV Videos **********************************************	
'<div class="bbvideo"><object width="425" height="350" align="top" data="http://www.garagetv.be/v/$1/v.aspx" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.garagetv.be/v/$1/v.aspx" /><param name="quality" value="best" /><embed src="http://www.garagetv.be/v/$1/v.aspx" width="425" height="350" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end GarageTV Videos ************************************************
					 
					 
//****** embed Revver Videos ************************************************	
'<div class="bbvideo"><object width="480" height="392" align="top" data="http://flash.revver.com/player/1.0/player.swf?mediaId=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://flash.revver.com/player/1.0/player.swf?mediaId=$1" /><param name="quality" value="best" /><embed src="http://flash.revver.com/player/1.0/player.swf?mediaId=$1" width="480" height="392" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Revver Videos **************************************************
					 				 
					 
//****** embed Guba Videos **************************************************	
'<div class="bbvideo"><object width="480" height="392" align="top" data="http://www.guba.com/f/root.swf?video_url=http://free.guba.com/uploaditem/$1/flash.flv" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.guba.com/f/root.swf?video_url=http://free.guba.com/uploaditem/$1/flash.flv" /><param name="quality" value="best" /><embed src="http://www.guba.com/f/root.swf?video_url=http://free.guba.com/uploaditem/$1/flash.flv" width="480" height="392" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Guba Videos ****************************************************
					 

//****** embed mySpace Videos ***********************************************	
'<div class="bbvideo"><object width="480" height="392" align="top data="http://lads.myspace.com/videos/vplayer.swf?m=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://lads.myspace.com/videos/vplayer.swf?m=$1" /><param name="quality" value="best" /><embed src="http://lads.myspace.com/videos/vplayer.swf?m=$1" width="480" height="392" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end mySpace Videos *************************************************
					 
					
//****** embed Yahoo Videos **************************************************	
'<div class="bbvideo"><object width="480" height="392" align="top" data="http://us.i1.yimg.com/cosmos.bcst.yahoo.com/player/media/swf/FLVVideoSolo.swf?id=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://us.i1.yimg.com/cosmos.bcst.yahoo.com/player/media/swf/FLVVideoSolo.swf?id=$1" /><param name="quality" value="best" /><embed src="http://us.i1.yimg.com/cosmos.bcst.yahoo.com/player/media/swf/FLVVideoSolo.swf?id=$1" width="480" height="392" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Yahoo Videos ***************************************************
					 
					 	
//****** embed Aniboom Videos ***********************************************	
'<div class="bbvideo"><object width="448" height="372" align="top" data="http://api.aniboom.com/embedded.swf?videoar=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://api.aniboom.com/embedded.swf?videoar=$1" /><param name="quality" value="best" /><embed src="http://api.aniboom.com/embedded.swf?videoar=$1" width="448" height="372" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Aniboom Videos *************************************************	
					 	
				
//****** embed Veoh Videos **************************************************	
'<div class="bbvideo"><object width="540" height="438" align="top" data="http://www.veoh.com/videodetails2.swf?permalinkId=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.veoh.com/videodetails2.swf?permalinkId=$1" /><param name="quality" value="best" /><embed src="http://www.veoh.com/videodetails2.swf?permalinkId=$1" width="540" height="438" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Veoh Videos **************************************************** 	
	

//****** embed VideoJug Videos **********************************************	
'<div class="bbvideo"><object width="400" height="345" align="top" data="http://www.videojug.com/film/player?id=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.videojug.com/film/player?id=$1" /><param name="quality" value="best" /><embed src="http://www.videojug.com/film/player?id=$1" width="400" height="345" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end VideoJug Videos ************************************************ 
					 	 
					 
//****** embed VSocial Videos ***********************************************	
'<div class="bbvideo"><object width="400" height="410" align="top" data="http://static.vsocial.com/flash/ups.swf?d=$1&a=0" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://static.vsocial.com/flash/ups.swf?d=$1&a=0" /><param name="quality" value="best" /><embed src="http://static.vsocial.com/flash/ups.swf?d=$1&a=0" width="400" height="410" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end VSocial Videos ************************************************* 					 
					 					 		 	 					 
		
//****** embed eSnips Videos ************************************************	
'<div class="bbvideo"><object width="320" height="285" align="top" data="http://www.esnips.com//3rd/flvplayer/esnips_flvplayer12.swf?xmlURL=http://www.esnips.com//flashxml/1/$1 \" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.esnips.com//3rd/flvplayer/esnips_flvplayer12.swf?xmlURL=http://www.esnips.com//flashxml/1/$1 \" /><param name="quality" value="best" /><param name="flashvars"  value= "autostart=false" /><embed src="http://www.esnips.com//3rd/flvplayer/esnips_flvplayer12.swf?xmlURL=http://www.esnips.com//flashxml/1/$1" quality="best" height="300" width="400" flashvars="autostart=false" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer"></embed></object></div>',	
//****** end eSnips Videos ************************************************** 			 					 


//****** embed Brightcove Videos ********************************************	
'<div class="bbvideo"><object width="486" height="412" align="top" data="http://admin.brightcove.com/destination/player/player.swf" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="always" /><param name="movie" value="http://admin.brightcove.com/destination/player/player.swf" /><param name="quality" value="best" /><param name="allowFullScreen" value="true" /><param name="flashvars"  value="allowFullScreen=true&servicesURL=http://www.brightcove.com&viewerSecureGatewayURL=https://www.brightcove.com&cdnURL=http://admin.brightcove.com&autoStart=false&initVideoId=$1" /><embed src="http://admin.brightcove.com/destination/player/player.swf?&initVideoId=$1" allowfullscreen="true" quality="best" width="486" height="412" flashvars="allowFullScreen=true&servicesURL=http://www.brightcove.com&viewerSecureGatewayURL=https://www.brightcove.com&cdnURL=http://admin.brightcove.com&autoStart=false" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer"></embed></object></div>',	
//****** end Brightcove Videos ********************************************** 



//****** embed MegaVideo ****************************************************	
'<div class="bbvideo"><object width="432" height="351" align="top" data="http://www.megavideo.com/v/$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.megavideo.com/v/$1" /><param name="quality" value="best" /><embed src="http://www.megavideo.com/v/$1" width="432" height="351" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end MegaVideo ******************************************************

//****** embed MegaVideo ****************************************************	
'<div class="bbvideo"><object width="432" height="351" align="top" data="http://www.megavideo.com/ep_gn.swf?v=$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.megavideo.com/ep_gn.swf?v=$1" /><param name="quality" value="best" /><embed src="http://www.megavideo.com/ep_gn.swf?v=$1" width="432" height="351" quality="best" align="top" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end MegaVideo ******************************************************

					 
					 
//****** embed Stage6 divX Videos with dimensions settings inside BBCode ****
'<div class="bbvideo"><object width="$1" height="$2" align="top" data="http://video.stage6.com/$3/.divx\" classid="clsid:67DABFBF-D0AB-41fa-9C46-CC0F21721616"  codebase="http://go.divx.com/plugin/DivXBrowserPlugin.cab"><param name="autoplay" value="false"><param name="src" value="http://video.stage6.com/$3/.divx\" /<param name="custommode" value="Stage6" /><param name="showpostplaybackad" value="false" /><embed src="http://video.stage6.com/$3/.divx" width="$1" height="$2" align="top" showpostplaybackad="false" custommode="Stage6" autoplay="false" type="video/divx" pluginspage="http://go.divx.com/plugin/download/"  /></embed></object>
<br/>No video? Get the DivX Web Player for <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayerInstaller.exe">Windows</a> or <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayer.dmg">Mac</a></div>',
//****** end Stage6 divX Videos ********************************************* 
					 					 
//****** embed Stage6 divX Videos *******************************************	
'<div class="bbvideo"><object width="640" height="480" align="top" data="http://video.stage6.com/$1/.divx\" classid="clsid:67DABFBF-D0AB-41fa-9C46-CC0F21721616"  codebase="http://go.divx.com/plugin/DivXBrowserPlugin.cab"><param name="autoplay" value="false"><param name="src" value="http://video.stage6.com/$1/.divx\" /<param name="custommode" value="Stage6" /><param name="showpostplaybackad" value="false" /><embed src="http://video.stage6.com/$1/.divx" width="640" height="480" align="top" showpostplaybackad="false" custommode="Stage6" autoplay="false" type="video/divx" pluginspage="http://go.divx.com/plugin/download/"  /></embed></object>
<br/>No video? Get the DivX Web Player for <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayerInstaller.exe">Windows</a> or <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayer.dmg">Mac</a></div>',
//****** end Stage6 divX Videos ********************************************* 
					 
					 
					 
					 
					 
//****** embed Virb Videos with dimensions settings inside BBCode **********	
'<div class="bbvideo"><object width="$1" height="$2" align="top" data="http://www.virb.com/external/video/$3" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.virb.com/external/video/$3" /><param name="quality" value="best" /><param name="salign" value="tl" /><param name="wmode" value="transparent" /><embed src="http://www.virb.com/external/video/$3" width="$1" height="$2" quality="best" salign="tl" align="top" wmode="transparent" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Virb Videos **************************************************** 
					 
//****** embed Virb Videos **************************************************	
'<div class="bbvideo"><object width="564" height="380" align="top" data="http://www.virb.com/external/video/$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0"><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="http://www.virb.com/external/video/$1" /><param name="quality" value="best" /><param name="salign" value="tl" /><param name="wmode" value="transparent" /><embed src="http://www.virb.com/external/video/$1" width="564" height="380" quality="best" salign="tl" align="top" wmode="transparent" allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></embed></object></div>',
//****** end Virb Videos **************************************************** 	






//++++++++++++++++++++++++++++++++++++++++++++ FLV Videos +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

//****** embed FLV for JW - Players *****************************************	
'<div class="bbvideo"><object width="464" height="380" data="mod_mediaplayer.swf" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=8,0,0,0"><param name="movie" value="mod_mediaplayer.swf" /><param name="menu" value="false" /><param name="quality" value="best" /><param name="allowFullScreen" value="true" /><param name="flashvars" value="frontcolor=0xEEEEEE&backcolor=0x222222&lightcolor=0xFFFFFF&autostart=false&usefullscreen=true&file=$1" /><embed src="mod_mediaplayer.swf" width="464" height="380" menu="false" allowfullscreen="true" flashvars="frontcolor=0xEEEEEE&backcolor=0x222222&lightcolor=0xFFFFFF&autostart=false&usefullscreen=true&file=$1" type="application/x-shockwave-flash" pluginspage= "http://www.macromedia.com/go/getflashplayer"/></embed></object></div>',
//****** end FLV for JW - Players *******************************************

//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//


//+++++++++++++++++++++++++++++++++++++++++++++ Mp3 Music ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

//****** embed Mp3 for JW - Players ******************************************	
'<div class="bbvideo"><object width="464" height="380" data="mod_mediaplayer.swf" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=8,0,0,0"><param name="movie" value="mod_mediaplayer.swf" /><param name="menu" value="false" /><param name="quality" value="best" /><param name="flashvars" value="flashvars="&height=20&width=320&frontcolor=0xEEEEEE&backcolor=0x444444&lightcolor=0xFFFFFF&showdownload=true&showicons=false&autostart=false&file=$1"" /><embed src="mod_mediaplayer.swf" width="320" height="20" menu="false" flashvars="&height=20&width=320&frontcolor=0xEEEEEE&backcolor=0x444444&lightcolor=0xFFFFFF&showdownload=true&showicons=false&autostart=false&file=$1" type="application/x-shockwave-flash" pluginspage= "http://www.macromedia.com/go/getflashplayer"/></embed></object></div>',
//****** end Mp3 for JW - Players *******************************************
					
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//					 
					 
	
	
	
					 
					 
					 					 
//++++++++++++++++++++++++++++++ DivX Videos with DivX WebPlayer PlugIn ++++++++++++++++++++++++++++++++++++++++++++++//
					 					 	
//****** embed divX Videos **************************************************						 	
'<div class="bbvideo"><object width="640" height="480" classid="clsid:67DABFBF-D0AB-41fa-9C46-CC0F21721616" codebase="http://go.divx.com/plugin/DivXBrowserPlugin.cab"><param name="autoPlay" value="false" /><param name="src" value="$1" /><embed src="$1" width="640" height="480" autoPlay="false" type="video/divx" pluginspage="http://go.divx.com/plugin/download/"></embed></object>
<br/>No video? Get the DivX Web Player for <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayerInstaller.exe">Windows</a> or <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayer.dmg">Mac</a>	</div>',	
//****** end divX Videos ****************************************************
					 				
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//	
			 				
//++++++++++++++++++++++++++++++ DivX Videos with dimensions settings inside BBCode ++++++++++++++++++++++++++++++++++//
					 					 	
//****** embed divX Videos **************************************************						 	
'<div class="bbvideo"><object width="$1" height="$2" classid="clsid:67DABFBF-D0AB-41fa-9C46-CC0F21721616" codebase="http://go.divx.com/plugin/DivXBrowserPlugin.cab"><param name="autoPlay" value="false" /><param name="src" value="$3" /><embed src="$3" width="$1" height="$2" autoPlay="false" type="video/divx" pluginspage="http://go.divx.com/plugin/download/"></embed></object>
<br/>No video? Get the DivX Web Player for <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayerInstaller.exe">Windows</a> or <a style="text-decoration: underline;" href="http://download.divx.com/player/DivXWebPlayer.dmg">Mac</a>	</div>',	
//****** end divX Videos ****************************************************
					 				
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//
					 									 
	
	
	
					 
					 
//+++++++++++++++++++++++++++++++++++++++ SWF with fixed width set to 100% ++++++++++++++++++++++++++++++++++++++++++++//
					 
//****** embed SWF **********************************************************
'<div class="bbvideo"><object width="100%" height="$1" align="middle" data="$2" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0" /><param name="scale" value="noscale" /><param name="allowScriptAccess" value="sameDomain" /><param name="movie" value="$2" /><param name="quality" value="best" /><param name=menu value="false"><embed align="middle" src="$2" quality="best" width="100%" height="$1" scale="noscale"  allowScriptAccess="sameDomain" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></object></div>',
//******** end SWF **********************************************************					 					 

//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//		 

//++++++++++++++++++++++++++++ SWF with width and height settings inside BBCode +++++++++++++++++++++++++++++++++++++++//


//****** embed SWF **********************************************************
'<div class="bbvideo"><object width="$1" height="$2" align="middle" data="$3" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0" /><param name="scale" value="noscale" /><param name="allowScriptAccess" value="never" /><param name="movie" value="$3" /><param name="quality" value="best" /><param name=menu value="false"><embed align="middle" src="$3" quality="best" width="$1" height="$2" scale="noscale" allowScriptAccess="never" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></object></div>',
//******** end SWF **********************************************************
					 
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

//++++++++++++++++++++++++++++ SWF with fixed width and height and cropping ++++++++++++++++++++++++++++++++++++++++++//


//****** embed SWF **********************************************************
'<div class="bbvideo"><object align="top" width="480" height="384" data="$1" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=7,0,0,0" /><param name="scale" value="noorder" /><param name="allowScriptAccess" value="never" /><param name="movie" value="$1" /><param name="quality" value="best" /><param name="bgcolor" value="#000000" /><param name="salign" value="tl" /><param name=menu value="false"><embed align="middle" src="$1" quality="best" bgcolor="#000000" width="480" height="384" scale="noorder" salign="tl" align="top" allowScriptAccess="never" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></object></div>',
//******** end SWF **********************************************************
				 
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//




				 					 
//+++++++++++++++++++++++++++++++++++++++ Quicktime with fixed width and height ++++++++++++++++++++++++++++++++++++++//
					 
//****** embed QuickTime ****************************************************
'<div class="bbvideo"><object width="480" height="376" align="top" classid="clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B" codebase="http://www.apple.com/qtactivex/qtplugin.cab" ><param name="type" value="video/quicktime" /><param name="scale" value="aspect"/><param name="cache" value="true"/><param name="src" value="$1"/><param name="autoplay" value="false"/><param name="controller" value="true"/><param name="loop" value="false"/><param name="bgcolor" value="transparent" /><embed width="480" height="376" align="top" src="$1" type="video/quicktime" controller="true" autoplay="false" bgcolor="transparent" cache="true" scale="aspect" loop="false" pluginspage="http://www.apple.com/quicktime/download/"></embed></object></div>',
//****** end QuickTime *******************************************************
					
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

//+++++++++++++++++++++++++++++++++ Quicktime with dimensions settings inside BBCode +++++++++++++++++++++++++++++++++//

//****** embed QuickTime ****************************************************
'<div class="bbvideo"><object width="$1" height="$2" align="top" classid="clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B" codebase="http://www.apple.com/qtactivex/qtplugin.cab" ><param name="type" value="video/quicktime" /><param name="scale" value="aspect"/><param name="cache" value="true"/><param name="src" value="$3"/><param name="autoplay" value="false"/><param name="controller" value="true"/><param name="loop" value="false"/><param name="bgcolor" value="transparent" /><embed width="$1" height="$2" src="$3" align="top" type="video/quicktime" controller="true" autoplay="false" bgcolor="transparent" cache="true" scale="aspect" loop="false" pluginspage="http://www.apple.com/quicktime/download/"></embed></object></div>',
//****** end QuickTime ******************************************************* 
										 
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//





//+++++++++++++++++++++++++++++++++ Windows Media with dimensions settings inside BBCode ++++++++++++++++++++++++++++++//

//****** embed Windows Media *************************************************
'<div class="bbvideo"><object width="$1" height="$2" classid="clsid:6BF52A52-394A-11D3-B153-00C04F79FAA6" standby="Loading Windows Media Player components..." type="application/x-oleobject"><param name="FileName" value="$3" /><param name="volume" value="-7000" /><param name="ShowControls" value="true" /><param name="ShowStatusBar" value="false" /><param name="ShowDisplay" value="false" /><param name="autostart" value="false" /><param name="autosize" value="true" /><param name="AnimationAtStart" value="false" /><embed width="$1" height="$2" src="$3" volume="-7000" AnimationAtStart="0" showcontrols="1" showstatusbar="0" showdisplay="0" autostart="0" autosize="1" type="application/x-mplayer2" pluginspage="http://www.microsoft.com/windows/windowsmedia/players.asp"></embed></object>
<br/>Using a Mac? Want to see this WMV with Quicktime? Get <a style="text-decoration: underline;" href="http://www.flip4mac.com/wmv_download.htm" onclick="window.open(this.href); return false;">flip4mac</a></div>',
//****** end Windows Media **************************************************** 
										 
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//

			
	
					 
					 );// end array - don't remove //
					 
					 
					 

//++++++++++++++++++++++++++++++++++++++++++++++++++++ End Easy Visual BBCode ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//	
//++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++//	 
	// This thing takes a while! :)
	$text = preg_replace($pattern, $replace, $text);

	return $text;
}


//
// Make hyperlinks clickable
//
function do_clickable($text)
{
	global $pun_user;

	$text = ' '.$text;

	$text = preg_replace('#([\s\(\)])(https?|ftp|news){1}://([\w\-]+\.([\w\-]+\.)*[\w]+(:[0-9]+)?(/[^"\s\(\)<\[]*)?)#ie', '\'$1\'.handle_url_tag(\'$2://$3\')', $text);
	$text = preg_replace('#([\s\(\)])(www|ftp)\.(([\w\-]+\.)*[\w]+(:[0-9]+)?(/[^"\s\(\)<\[]*)?)#ie', '\'$1\'.handle_url_tag(\'$2.$3\', \'$2.$3\')', $text);

	return substr($text, 1);
}


//
// Convert a series of smilies to images
//
function do_smilies($text)
{
	global $smiley_text, $smiley_img;

	$text = ' '.$text.' ';

	$num_smilies = count($smiley_text);
	for ($i = 0; $i < $num_smilies; ++$i)
		$text = preg_replace("#(?<=.\W|\W.|^\W)".preg_quote($smiley_text[$i], '#')."(?=.\W|\W.|\W$)#m", '$1<img src="img/smilies/'.$smiley_img[$i].'" width="15" height="15" alt="'.substr($smiley_img[$i], 0, strrpos($smiley_img[$i], '.')).'" />$2', $text);

	return substr($text, 1, -1);
}


//
// Parse message text
//
function parse_message($text, $hide_smilies)
{
	global $pun_config, $lang_common, $pun_user;

	if ($pun_config['o_censoring'] == '1')
		$text = censor_words($text);

	// Convert applicable characters to HTML entities
	$text = pun_htmlspecialchars($text);

	// If the message contains a code tag we have to split it up (text within [code][/code] shouldn't be touched)
	if (strpos($text, '[code]') !== false && strpos($text, '[/code]') !== false)
	{
		list($inside, $outside) = split_text($text, '[code]', '[/code]');
		$outside = array_map('ltrim', $outside);
		$text = implode('<">', $outside);
	}

	if ($pun_config['o_make_links'] == '1')
		$text = do_clickable($text);

	if ($pun_config['o_smilies'] == '1' && $pun_user['show_smilies'] == '1' && $hide_smilies == '0')
		$text = do_smilies($text);

	if ($pun_config['p_message_bbcode'] == '1' && strpos($text, '[') !== false && strpos($text, ']') !== false)
	{
		$text = do_bbcode($text);

		if ($pun_config['p_message_img_tag'] == '1')
		{
//			$text = preg_replace('#\[img\]((ht|f)tps?://)([^\s<"]*?)\.(jpg|jpeg|png|gif)\[/img\]#e', 'handle_img_tag(\'$1$3.$4\')', $text);
			$text = preg_replace('#\[img\]((ht|f)tps?://)([^\s<"]*?)\[/img\]#e', 'handle_img_tag(\'$1$3\')', $text);
		}
	}

	// Deal with newlines, tabs and multiple spaces
	$pattern = array("\n", "\t", '  ', '  ');
	$replace = array('<br />', '&nbsp; &nbsp; ', '&nbsp; ', ' &nbsp;');
	$text = str_replace($pattern, $replace, $text);

	// If we split up the message before we have to concatenate it together again (code tags)
	if (isset($inside))
	{
		$outside = explode('<">', $text);
		$text = '';

		$num_tokens = count($outside);

		for ($i = 0; $i < $num_tokens; ++$i)
		{
			$text .= $outside[$i];
			if (isset($inside[$i]))
			{
				$num_lines = ((substr_count($inside[$i], "\n")) + 3) * 1.5;
				$height_str = ($num_lines > 35) ? '35em' : $num_lines.'em';
				$text .= '</p><div class="codebox"><div class="incqbox"><h4>'.$lang_common['Code'].':</h4><div class="scrollbox" style="height: '.$height_str.'"><pre>'.$inside[$i].'</pre></div></div></div><p>';
			}
		}
	}

	// Add paragraph tag around post, but make sure there are no empty paragraphs
	$text = str_replace('<p></p>', '', '<p>'.$text.'</p>');

	return $text;
}


//
// Parse signature text
//
function parse_signature($text)
{
	global $pun_config, $lang_common, $pun_user;

	if ($pun_config['o_censoring'] == '1')
		$text = censor_words($text);

	$text = pun_htmlspecialchars($text);

	if ($pun_config['o_make_links'] == '1')
		$text = do_clickable($text);

	if ($pun_config['o_smilies_sig'] == '1' && $pun_user['show_smilies'] != '0')
		$text = do_smilies($text);

	if ($pun_config['p_sig_bbcode'] == '1' && strpos($text, '[') !== false && strpos($text, ']') !== false)
	{
		$text = do_bbcode($text);

		if ($pun_config['p_sig_img_tag'] == '1')
		{
//			$text = preg_replace('#\[img\]((ht|f)tps?://)([^\s<"]*?)\.(jpg|jpeg|png|gif)\[/img\]#e', 'handle_img_tag(\'$1$3.$4\', true)', $text);
			$text = preg_replace('#\[img\]((ht|f)tps?://)([^\s<"]*?)\[/img\]#e', 'handle_img_tag(\'$1$3\', true)', $text);
		}
	}

	// Deal with newlines, tabs and multiple spaces
	$pattern = array("\n", "\t", '  ', '  ');
	$replace = array('<br />', '&nbsp; &nbsp; ', '&nbsp; ', ' &nbsp;');
	$text = str_replace($pattern, $replace, $text);

	return $text;
}
